@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
-
 import locale
 
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import models
 from django.utils.translation import ugettext as _
-from django.utils.translation import ugettext_lazy, ugettext_noop
 
 from openslides.utils.models import MinMaxIntegerField
 
@@ -52,7 +49,7 @@ class BaseVote(models.Model):
     class Meta:
         abstract = True
 
-    def __unicode__(self):
+    def __str__(self):
         return self.print_weight()
 
     def get_value(self):
@@ -69,23 +66,14 @@ class BaseVote(models.Model):
         return print_value(self.weight, percent_base)
 
 
-PERCENT_BASE_CHOICES = (
-    ('WITHOUT_INVALID', ugettext_lazy('Only all valid votes')),
-    ('WITH_INVALID', ugettext_lazy('All votes cast (including invalid votes)')),
-    ('DISABLED', ugettext_lazy('Disabled (no percents)')))
-
-
 class CollectDefaultVotesMixin(models.Model):
     """
     Mixin for a poll to collect the default vote values for valid votes,
     invalid votes and votes cast.
     """
-    votesvalid = MinMaxIntegerField(null=True, blank=True, min_value=-2,
-                                    verbose_name=ugettext_lazy('Valid votes'))
-    votesinvalid = MinMaxIntegerField(null=True, blank=True, min_value=-2,
-                                      verbose_name=ugettext_lazy('Invalid votes'))
-    votescast = MinMaxIntegerField(null=True, blank=True, min_value=-2,
-                                   verbose_name=ugettext_lazy('Votes cast'))
+    votesvalid = MinMaxIntegerField(null=True, blank=True, min_value=-2)
+    votesinvalid = MinMaxIntegerField(null=True, blank=True, min_value=-2)
+    votescast = MinMaxIntegerField(null=True, blank=True, min_value=-2)
 
     class Meta:
         abstract = True
@@ -98,40 +86,10 @@ class CollectDefaultVotesMixin(models.Model):
 
     def get_percent_base_choice(self):
         """
-        Returns one of the three strings in PERCENT_BASE_CHOICES.
+        Returns one of the strings of the percent base.
         """
         raise NotImplementedError('You have to provide a get_percent_base_choice() method.')
 
-    def print_votesvalid(self):
-        if self.get_percent_base_choice() == 'DISABLED':
-            value = print_value(self.votesvalid, None)
-        else:
-            value = print_value(self.votesvalid, self.get_percent_base())
-        return value
-
-    def print_votesinvalid(self):
-        if self.get_percent_base_choice() == 'WITH_INVALID':
-            value = print_value(self.votesinvalid, self.get_percent_base())
-        else:
-            value = print_value(self.votesinvalid, None)
-        return value
-
-    def print_votescast(self):
-        if self.get_percent_base_choice() == 'WITH_INVALID':
-            value = print_value(self.votescast, self.get_percent_base())
-        else:
-            value = print_value(self.votescast, None)
-        return value
-
-    def get_percent_base(self):
-        if self.get_percent_base_choice() == "WITHOUT_INVALID" and self.votesvalid > 0:
-            base = 100 / float(self.votesvalid)
-        elif self.get_percent_base_choice() == "WITH_INVALID" and self.votescast > 0:
-            base = 100 / float(self.votescast)
-        else:
-            base = None
-        return base
-
 
 class PublishPollMixin(models.Model):
     """
@@ -151,7 +109,7 @@ class BasePoll(models.Model):
     """
     Base poll class.
     """
-    vote_values = [ugettext_noop('votes')]
+    vote_values = ['Votes']
 
     class Meta:
         abstract = True
@@ -164,7 +122,7 @@ class BasePoll(models.Model):
             return True
         return False
 
-    def set_options(self, options_data=[]):
+    def set_options(self, options_data=[], skip_autoupdate=False):
         """
         Adds new option objects to the poll.
 
@@ -173,7 +131,7 @@ class BasePoll(models.Model):
         for option_data in options_data:
             option = self.get_option_class()(**option_data)
             option.poll = self
-            option.save()
+            option.save(skip_autoupdate=skip_autoupdate)
 
     def get_options(self):
         """
@@ -205,7 +163,7 @@ class BasePoll(models.Model):
         """
         return self.get_vote_class().objects.filter(option__poll__id=self.id)
 
-    def set_vote_objects_with_values(self, option, data):
+    def set_vote_objects_with_values(self, option, data, skip_autoupdate=False):
         """
         Creates or updates the vote objects for the poll.
         """
@@ -215,7 +173,7 @@ class BasePoll(models.Model):
             except ObjectDoesNotExist:
                 vote = self.get_vote_class()(option=option, value=value)
             vote.weight = data[value]
-            vote.save()
+            vote.save(skip_autoupdate=skip_autoupdate)
 
     def get_vote_objects_with_values(self, option_id):
         """
